| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Reflex.Bulmex.Html
Contents
Description
A root for an app, usefull for server side html rendering. has a neat api for the head tag, use this if that api your needs.
Synopsis
- htmlWidget :: DomBuilder t m => HeadSettings -> m a -> m a
- data HeadSettings = HeadSettings {
- _head_js :: [HeadScript]
- _head_css :: [URI]
- _head_title :: Text
- head_js :: Lens' HeadSettings [HeadScript]
- head_css :: Lens' HeadSettings [URI]
- head_title :: Lens' HeadSettings Text
- data HeadScript = HeadScript {}
- script_uri :: Lens' HeadScript URI
- script_is_async :: Lens' HeadScript Bool
- defScript :: HeadScript
- defSettings :: HeadSettings
Documentation
htmlWidget :: DomBuilder t m => HeadSettings -> m a -> m a Source #
Adds the core html tags. we already know most of the head.
Head tag stuff
data HeadSettings Source #
Constructors
| HeadSettings | |
Fields
| |
Instances
| Show HeadSettings Source # | |
Defined in Reflex.Bulmex.Html Methods showsPrec :: Int -> HeadSettings -> ShowS # show :: HeadSettings -> String # showList :: [HeadSettings] -> ShowS # | |
| Generic HeadSettings Source # | |
Defined in Reflex.Bulmex.Html Associated Types type Rep HeadSettings :: * -> * # | |
| type Rep HeadSettings Source # | |
Defined in Reflex.Bulmex.Html type Rep HeadSettings = D1 (MetaData "HeadSettings" "Reflex.Bulmex.Html" "bulmex-1.0.0-9xRl5QIfgDw3EScjT9Fxl8" False) (C1 (MetaCons "HeadSettings" PrefixI True) (S1 (MetaSel (Just "_head_js") NoSourceUnpackedness NoSourceStrictness DecidedLazy) (Rec0 [HeadScript]) :*: (S1 (MetaSel (Just "_head_css") NoSourceUnpackedness NoSourceStrictness DecidedLazy) (Rec0 [URI]) :*: S1 (MetaSel (Just "_head_title") NoSourceUnpackedness NoSourceStrictness DecidedLazy) (Rec0 Text)))) | |
data HeadScript Source #
Constructors
| HeadScript | |
Fields
| |
Instances
| Show HeadScript Source # | |
Defined in Reflex.Bulmex.Html Methods showsPrec :: Int -> HeadScript -> ShowS # show :: HeadScript -> String # showList :: [HeadScript] -> ShowS # | |
| Generic HeadScript Source # | |
Defined in Reflex.Bulmex.Html Associated Types type Rep HeadScript :: * -> * # | |
| type Rep HeadScript Source # | |
Defined in Reflex.Bulmex.Html type Rep HeadScript = D1 (MetaData "HeadScript" "Reflex.Bulmex.Html" "bulmex-1.0.0-9xRl5QIfgDw3EScjT9Fxl8" False) (C1 (MetaCons "HeadScript" PrefixI True) (S1 (MetaSel (Just "_script_is_async") NoSourceUnpackedness NoSourceStrictness DecidedLazy) (Rec0 Bool) :*: S1 (MetaSel (Just "_script_uri") NoSourceUnpackedness NoSourceStrictness DecidedLazy) (Rec0 URI))) | |